==> quiz-maker.6.3.7.6.zip: quiz-maker/admin/partials/features/quiz-maker-plugin-featured-display.php <==
<!-- This file should primarily consist of HTML with a little bit of PHP. -->
<div class="wrap">
    <h1 id="ays-quiz-intro-title"><?php echo __('Please feel free to use our other awesome plugins!', $this->plugin_name); ?></h1>
    <div class="ays-quiz-cards-block">
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-poll-128x128.png" alt="Poll Maker">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Poll Maker', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Create amazing online polls for your WordPress website super easily.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Build up various types of polls in a minute and get instant feedback on any topic or product.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/poll-maker/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/poll-maker/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-survey-128x128.png" alt="Survey Maker">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Survey Maker', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Make amazing online surveys and get real-time feedback quickly and easily.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Learn what your website visitors want, need, and expect with the help of Survey Maker. Build surveys without limiting your needs.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/survey-maker/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/survey-maker/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-popup-128x128.png" alt="Popup Box">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Popup Box', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Popup everything you want! Create informative and promotional popups all in one plugin.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Attract your visitors and convert them into email subscribers and paying customers.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/ays-popup-box/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/popup-box/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-gallery-128x128.jpg" alt="Gallery - Photo Gallery">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Gallery Photo Gallery', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Create unlimited galleries and include unlimited images in those galleries.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Represent images in an attractive way. Attract people with your own single and multiple free galleries from your photo library.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/gallery-photo-gallery/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/photo-gallery/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-sccp-128x128.png" alt="Secure Copy Content Protection">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Secure Copy Content Protection', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Disable the right click, copy paste, content selection and copy shortcut keys on your website.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Protect web content from being plagiarized. Prevent plagiarism from your website with this easy to use plugin.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/secure-copy-content-protection/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/secure-copy-content-protection/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/pd-logo-128x128.png" alt="Personal Dictionary">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Personal Dictionary', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Allow your students to create personal dictionary, study and memorize the words.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Allow your users to create their own digital dictionaries and learn new words and terms as fastest as possible.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/personal-dictionary/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/personal-dictionary/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
    </div>
    <div class="ays-quiz-see-all">
        <a href="https://ays-pro.com/wordpress" target="_blank" class="ays-quiz-all-btn"><?php echo __('See All Plugins', $this->plugin_name); ?></a>
    </div>

    <!-- <p class="text-center coming-soon">And more and more is <span>Coming Soon</span></p> -->
</div>

==> quiz-maker_v21.7.5.zip: quiz-maker/admin/partials/features/quiz-maker-plugin-featured-display.php <==
<!-- This file should primarily consist of HTML with a little bit of PHP. -->
<div class="wrap" id="ays-quiz-cards-main-block">
    <div class="ays-quiz-heading-box">
        <div class="ays-quiz-wordpress-user-manual-box">
            <a href="https://ays-pro.com/wordpress-quiz-maker-user-manual" target="_blank"><?php echo __("View Documentation", $this->plugin_name); ?></a>
        </div>
    </div>
    <h1 id="ays-quiz-intro-title"><?php echo __('Please feel free to use our other awesome plugins!', $this->plugin_name); ?></h1>
    <div class="ays-quiz-cards-block">
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-poll-128x128.png" alt="Poll Maker">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Poll Maker', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Create amazing online polls for your WordPress website super easily.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Build up various types of polls in a minute and get instant feedback on any topic or product.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/poll-maker/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/poll-maker/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-survey-128x128.png" alt="Survey Maker">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Survey Maker', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Make amazing online surveys and get real-time feedback quickly and easily.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Learn what your website visitors want, need, and expect with the help of Survey Maker. Build surveys without limiting your needs.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/survey-maker/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/survey-maker/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-popup-128x128.png" alt="Popup Box">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Popup Box', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Popup everything you want! Create informative and promotional popups all in one plugin.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Attract your visitors and convert them into email subscribers and paying customers.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/ays-popup-box/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/popup-box/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-gallery-128x128.png" alt="Gallery - Photo Gallery">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Gallery Photo Gallery', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Create unlimited galleries and include unlimited images in those galleries.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Represent images in an attractive way. Attract people with your own single and multiple free galleries from your photo library.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/gallery-photo-gallery/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/photo-gallery/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/icon-sccp-128x128.png" alt="Secure Copy Content Protection">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Secure Copy Content Protection', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Disable the right click, copy paste, content selection and copy shortcut keys on your website.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Protect web content from being plagiarized. Prevent plagiarism from your website with this easy to use plugin.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/secure-copy-content-protection/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/secure-copy-content-protection/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
        <div class="ays-quiz-card">
            <div class="ays-quiz-card__content flexible">
                <div class="ays-quiz-card__content-img-box">
                    <img class="ays-quiz-card__img" src="<?php echo AYS_QUIZ_ADMIN_URL; ?>/images/icons/pd-logo-128x128.png" alt="Personal Dictionary">
                </div>
                <div class="ays-quiz-card__text-block">
                    <h5 class="ays-quiz-card__title"><?php echo __('Personal Dictionary', $this->plugin_name); ?></h5>
                    <p class="ays-quiz-card__text"><?php echo __('Allow your students to create personal dictionary, study and memorize the words.', $this->plugin_name); ?>
                        <span class="ays-quiz-card__text-hidden">
                            <?php echo __('Allow your users to create their own digital dictionaries and learn new words and terms as fastest as possible.', $this->plugin_name); ?>
                        </span>
                    </p>
                </div>
            </div>
            <div class="ays-quiz-card__footer">
                <a target="_blank" href="https://wordpress.org/plugins/personal-dictionary/" class="ays-quiz-card__btn-info">WP.org</a>
                <a target="_blank" href="https://ays-pro.com/wordpress/personal-dictionary/" class="ays-quiz-card__btn-primary"><?php echo __('Buy Now', $this->plugin_name); ?></a>
            </div>
        </div>
    </div>
    <div class="ays-quiz-see-all">
        <a href="https://ays-pro.com/wordpress" target="_blank" class="ays-quiz-all-btn"><?php echo __('See All Plugins', $this->plugin_name); ?></a>
    </div>

    <!-- <p class="text-center coming-soon">And more and more is <span>Coming Soon</span></p> -->
</div>
